summaryrefslogtreecommitdiffstats
path: root/noatun/library/noatun/playlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/noatun/playlist.h')
-rw-r--r--noatun/library/noatun/playlist.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/noatun/library/noatun/playlist.h b/noatun/library/noatun/playlist.h
index 37eabb0b..013d63a4 100644
--- a/noatun/library/noatun/playlist.h
+++ b/noatun/library/noatun/playlist.h
@@ -1,10 +1,10 @@
#ifndef NOATUNPLAYLIST_H
#define NOATUNPLAYLIST_H
-#include <qobject.h>
+#include <tqobject.h>
#include <kurl.h>
-#include <qdict.h>
-#include <qstringlist.h>
+#include <tqdict.h>
+#include <tqstringlist.h>
#include <cassert>
#include <kdemacros.h>
@@ -35,7 +35,7 @@ public:
/**
* Noatun asks your playlist for properties. It is your
* responsiblity to store the information. But usually a QMap<QString,QString>
* is enough.
*
* If you return the default value, the default should not
@@ -43,30 +43,30 @@ public:
*
* This returns the property, or def if such a property doesn't exist
**/
- virtual QString property(const QString &key, const QString &def=0) const=0;
+ virtual TQString property(const TQString &key, const TQString &def=0) const=0;
/**
* This sets the property with the given key and value.
*
- * Important: If you use a QMap, you'll have to remove the current
+ * Important: If you use a TQMap, you'll have to remove the current
* item before adding a new one
**/
- virtual void setProperty(const QString &key, const QString &property)=0;
+ virtual void setProperty(const TQString &key, const TQString &property)=0;
/**
* remove the item with given key
**/
- virtual void clearProperty(const QString &key)=0;
+ virtual void clearProperty(const TQString &key)=0;
/**
* return a list of property keys
**/
- virtual QStringList properties() const=0;
+ virtual TQStringList properties() const=0;
/**
* return whether if the given key exists
**/
- virtual bool isProperty(const QString &key) const=0;
+ virtual bool isProperty(const TQString &key) const=0;
/**
* return the title of the song. By default, this will
@@ -78,7 +78,7 @@ public:
*
* you shouldn't need to override this.
**/
- virtual QString title() const;
+ virtual TQString title() const;
/**
* the true filename of the song, remote or local
@@ -93,18 +93,18 @@ public:
* first, this checks for the property "mimetype", else
* it'l ask KMimeType based on file()
**/
- virtual QCString mimetype() const;
+ virtual TQCString mimetype() const;
/**
* first, checks for the property "playObject", else,
* it'l ask aRts
**/
- virtual QCString playObject() const;
+ virtual TQCString playObject() const;
/**
* return the filename to send to the playobject
**/
- virtual QString file() const { return url().path(); }
+ virtual TQString file() const { return url().path(); }
/**
* what's the length of the song, in milliseconds?
@@ -120,7 +120,7 @@ public:
* returns a friendly representation of the length
* of this file
**/
- QString lengthString() const;
+ TQString lengthString() const;
/**
* compare yourself with the given PlaylistItemData
@@ -243,31 +243,31 @@ public:
bool operator !=(const PlaylistItemData *i) const
{ return ! (*this->data()==*i); }
- QString property(const QString &key, const QString &def=0) const
+ TQString property(const TQString &key, const TQString &def=0) const
{
assert(mData);
return mData->property(key, def);
}
- void setProperty(const QString &key, const QString &property)
+ void setProperty(const TQString &key, const TQString &property)
{
assert(mData);
const_cast<PlaylistItemData*>(mData)->setProperty(key, property);
}
- void clearProperty(const QString &key)
+ void clearProperty(const TQString &key)
{
assert(mData);
const_cast<PlaylistItemData*>(mData)->clearProperty(key);
}
- QStringList properties() const
+ TQStringList properties() const
{
assert(mData);
return mData->properties();
}
- bool isProperty(const QString &key) const
+ bool isProperty(const TQString &key) const
{
assert(mData);
return mData->isProperty(key);
@@ -280,11 +280,11 @@ public:
const_cast<PlaylistItemData*>(mData)->setUrl(url);
}
- QCString mimetype() const { assert(mData); return mData->mimetype(); }
- QCString playObject() const { assert(mData); return mData->playObject(); }
- QString file() const { assert(mData); return mData->file(); }
+ TQCString mimetype() const { assert(mData); return mData->mimetype(); }
+ TQCString playObject() const { assert(mData); return mData->playObject(); }
+ TQString file() const { assert(mData); return mData->file(); }
- QString title() const
+ TQString title() const
{
assert(mData);
return mData->title();
@@ -302,7 +302,7 @@ public:
mData->setLength(ms);
}
- QString lengthString() const { assert(mData); return mData->lengthString(); }
+ TQString lengthString() const { assert(mData); return mData->lengthString(); }
void remove() { assert(mData); mData->remove(); }
@@ -331,7 +331,7 @@ class Playlist : public QObject
Q_OBJECT
friend class PlaylistItemData;
public:
- Playlist(QObject *parent, const char *name);
+ Playlist(TQObject *parent, const char *name);
/**
* on playlist unload, your playlist must
* have current()==0 and emit playCurrent
@@ -432,8 +432,8 @@ public:
* to the items in the playlist. The keys
* are always compared with case sensitivity
**/
- virtual QValueList<PlaylistItem> select(
- const QStringList &keys, const QStringList &values,
+ virtual TQValueList<PlaylistItem> select(
+ const TQStringList &keys, const TQStringList &values,
int limit=-1, bool exact=false, bool caseSensitive=false
);
@@ -443,21 +443,21 @@ public:
* both of these (with different mechanisms if need be)
* for speed
**/
- virtual QValueList<PlaylistItem> select(
- const QString &key, const QString &value,
+ virtual TQValueList<PlaylistItem> select(
+ const TQString &key, const TQString &value,
int limit=-1, bool exact=false, bool caseSensitive=false
);
/**
* exactly the same as the above, except converts
* the const char* to QString (utf8)
**/
- inline QValueList<PlaylistItem> select(
+ inline TQValueList<PlaylistItem> select(
const char *key, const char *value,
int limit=-1, bool exact=false, bool caseSensitive=false
)
{
return select(
- QString(key), QString(value),
+ TQString(key), TQString(value),
limit, exact, caseSensitive
);
}
@@ -35,7 +35,7 @@ public:
/**
* Noatun asks your playlist for properties. It is your
- * responsiblity to store the information. But usually a QMap<QString,QString>
+ * responsiblity to store the information. But usually a TQMap<TQString,TQString>
* is enough.
*
@@ -443,21 +443,21 @@ public:
/**
* exactly the same as the above, except converts
- * the const char* to QString (utf8)
+ * the const char* to TQString (utf8)
**/